@@ -20,6 +20,7 @@
 package org.apache.cxf.jaxws;
 
 import java.io.ByteArrayInputStream;
+import java.io.Closeable;
 import java.io.IOException;
 import java.io.StringWriter;
 import java.net.HttpURLConnection;
@@ -60,6 +61,7 @@ import org.apache.cxf.binding.soap.model.SoapBindingInfo;
 import org.apache.cxf.binding.soap.model.SoapOperationInfo;
 import org.apache.cxf.binding.soap.saaj.SAAJInInterceptor;
 import org.apache.cxf.binding.soap.saaj.SAAJOutInterceptor;
+import org.apache.cxf.binding.soap.saaj.SAAJUtils;
 import org.apache.cxf.common.i18n.Message;
 import org.apache.cxf.common.logging.LogUtils;
 import org.apache.cxf.common.util.StringUtils;
@@ -89,7 +91,7 @@ import org.apache.cxf.staxutils.StaxSource;
 import org.apache.cxf.staxutils.StaxUtils;
 import org.apache.cxf.ws.addressing.WSAddressingFeature;
 
-public class DispatchImpl<T> implements Dispatch<T>, BindingProvider {
+public class DispatchImpl<T> implements Dispatch<T>, BindingProvider, Closeable {
     private static final Logger LOG = LogUtils.getL7dLogger(DispatchImpl.class);
     private static final String DISPATCH_NS = "http://cxf.apache.org/jaxws/dispatch";
     private static final String INVOKE_NAME = "Invoke";
@@ -304,7 +306,8 @@ public class DispatchImpl<T> implements Dispatch<T>, BindingProvider {
                 getRequestContext().put("unwrap.jaxb.element", unwrapProperty);
             }
             QName opName = (QName)getRequestContext().get(MessageContext.WSDL_OPERATION);
-                       
+            boolean findDispatchOp = Boolean.TRUE.equals(getRequestContext().get("find.dispatch.operation"));
+            
             if (opName == null) {
                 opName = isOneWay ? INVOKE_ONEWAY_QNAME : INVOKE_QNAME;
             } else {
@@ -315,28 +318,31 @@ public class DispatchImpl<T> implements Dispatch<T>, BindingProvider {
                 }
             }
             
-            //CXF-2836 : find the operation for the dispatched object 
-            boolean wsaEnabled = false;
-            // the feature list to be searched is the endpoint and the bus's lists
-            List<AbstractFeature> endpointFeatures 
-                = ((JaxWsClientEndpointImpl)client.getEndpoint()).getFeatures();
-            List<AbstractFeature> allFeatures;
-            if (client.getBus().getFeatures() != null) {
-                allFeatures = new ArrayList<AbstractFeature>(endpointFeatures.size() 
-                    + client.getBus().getFeatures().size());
-                allFeatures.addAll(endpointFeatures);
-                allFeatures.addAll(client.getBus().getFeatures());
-            } else {
-                allFeatures = endpointFeatures;
-            }
-            for (AbstractFeature feature : allFeatures) {
-                if (feature instanceof WSAddressingFeature) {
-                    wsaEnabled = true; 
+            //CXF-2836 : find the operation for the dispatched object
+            // if findDispatchOp is already true, skip the addressing feature lookup.
+            // if the addressing feature is enabled, set findDispatchOp to true
+            if (!findDispatchOp) {
+                // the feature list to be searched is the endpoint and the bus's lists
+                List<AbstractFeature> endpointFeatures 
+                    = ((JaxWsClientEndpointImpl)client.getEndpoint()).getFeatures();
+                List<AbstractFeature> allFeatures;
+                if (client.getBus().getFeatures() != null) {
+                    allFeatures = new ArrayList<AbstractFeature>(endpointFeatures.size() 
+                        + client.getBus().getFeatures().size());
+                    allFeatures.addAll(endpointFeatures);
+                    allFeatures.addAll(client.getBus().getFeatures());
+                } else {
+                    allFeatures = endpointFeatures;
+                }
+                for (AbstractFeature feature : allFeatures) {
+                    if (feature instanceof WSAddressingFeature) {
+                        findDispatchOp = true; 
+                    }
                 }
             }
             Map<String, QName> payloadOPMap = 
                 createPayloadEleOpNameMap(client.getEndpoint().getBinding().getBindingInfo());
-            if (wsaEnabled && !payloadOPMap.isEmpty()) {
+            if (findDispatchOp && !payloadOPMap.isEmpty()) {
                 String payloadElementName = null;              
                 if (obj instanceof javax.xml.transform.Source) {
                     try {
@@ -360,10 +366,15 @@ public class DispatchImpl<T> implements Dispatch<T>, BindingProvider {
 
                 if (payloadElementName != null) {
                     QName dispatchedOpName = payloadOPMap.get(payloadElementName);
-                    BindingOperationInfo bop = client.getEndpoint().getBinding().getBindingInfo()
-                        .getOperation(opName);
-                    if (bop != null) {
-                        bop.setProperty("dispatchToOperation", dispatchedOpName);
+                    if (null != dispatchedOpName) {
+                        BindingOperationInfo bop = client.getEndpoint().getBinding().getBindingInfo()
+                          .getOperation(opName);
+                        BindingOperationInfo dbop = client.getEndpoint().getBinding().getBindingInfo()
+                          .getOperation(dispatchedOpName);
+                        if (bop != null) {
+                            // set the actual binding operation object to this dispatch operation
+                            bop.setProperty("dispatchToOperation", dbop);
+                        }
                     }
                 }
             } 
@@ -385,7 +396,7 @@ public class DispatchImpl<T> implements Dispatch<T>, BindingProvider {
         checkError();
         client.setExecutor(getClient().getEndpoint().getExecutor());
 
-        ClientCallback callback = new JaxwsClientCallback<T>(asyncHandler);
+        ClientCallback callback = new JaxwsClientCallback<T>(asyncHandler, this);
              
         Response<T> ret = new JaxwsResponseCallback<T>(callback);
         try {
@@ -412,7 +423,7 @@ public class DispatchImpl<T> implements Dispatch<T>, BindingProvider {
 
     @SuppressWarnings("unchecked")
     public Response<T> invokeAsync(T obj) {
-        return (Response)invokeAsync(obj, null);
+        return (Response<T>)invokeAsync(obj, null);
     }
 
     public void invokeOneWay(T obj) {
@@ -451,7 +462,7 @@ public class DispatchImpl<T> implements Dispatch<T>, BindingProvider {
     private String getPayloadElementName(SOAPMessage soapMessage) {
         try {            
             // we only care about the first element node, not text nodes
-            Element element = DOMUtils.getFirstElement(soapMessage.getSOAPBody());
+            Element element = DOMUtils.getFirstElement(SAAJUtils.getBody(soapMessage));
             if (element != null) {
                 return DOMUtils.getElementQName(element).toString();
             }
@@ -499,7 +510,7 @@ public class DispatchImpl<T> implements Dispatch<T>, BindingProvider {
             }
         }
         for (BindingOperationInfo bop : bindingInfo.getOperations()) {
-            SoapOperationInfo soi = (SoapOperationInfo)bop.getExtensor(SoapOperationInfo.class);
+            SoapOperationInfo soi = bop.getExtensor(SoapOperationInfo.class);
             if (soi != null) {
                 // operation style overrides binding style, if present
                 String operationStyle = soi.getStyle() != null ? soi.getStyle() : bindingStyle;  
@@ -520,5 +531,9 @@ public class DispatchImpl<T> implements Dispatch<T>, BindingProvider {
         }
         return payloadElementMap;
     }
+
+    public void close() throws IOException {
+        client.destroy();
+    }
     
 }
