@@ -55,7 +55,7 @@ public class ServerFactoryTest extends AbstractSimpleFrontendTest {
         assertTrue(server.getDestination() instanceof CustomDestination);
     }
     
-    public static interface TestService<P> {
+    public interface TestService<P> {
         int open(P args);
         void close(int handle);
     }
@@ -96,7 +96,7 @@ public class ServerFactoryTest extends AbstractSimpleFrontendTest {
                   new Class[] {GreetMe.class, GreetMeOneWay.class});
         svrBean.setProperties(props);
         Server serv = svrBean.create();
-        Class[] extraClass = ((JAXBDataBinding)serv.getEndpoint().getService()
+        Class<?>[] extraClass = ((JAXBDataBinding)serv.getEndpoint().getService()
                 .getDataBinding()).getExtraClass();
         assertEquals(extraClass.length, 2);
         assertEquals(extraClass[0], GreetMe.class);
