@@ -29,14 +29,18 @@ import org.apache.cxf.message.ExchangeImpl;
 import org.apache.cxf.message.Message;
 import org.apache.cxf.message.MessageContentsList;
 import org.apache.cxf.message.MessageImpl;
-import org.apache.cxf.ws.addressing.AddressingPropertiesImpl;
 import org.apache.cxf.ws.addressing.AttributedURIType;
 import org.apache.cxf.ws.addressing.ContextUtils;
 import org.apache.cxf.ws.addressing.JAXWSAConstants;
+import org.apache.cxf.ws.addressing.impl.AddressingPropertiesImpl;
 import org.apache.cxf.ws.rm.manager.AcksPolicyType;
 import org.apache.cxf.ws.rm.manager.DestinationPolicyType;
-import org.easymock.classextension.EasyMock;
-import org.easymock.classextension.IMocksControl;
+import org.apache.cxf.ws.rm.v200502.CreateSequenceResponseType;
+import org.apache.cxf.ws.rm.v200502.CreateSequenceType;
+import org.apache.cxf.ws.rm.v200502.Expires;
+import org.apache.cxf.ws.rm.v200502.OfferType;
+import org.easymock.EasyMock;
+import org.easymock.IMocksControl;
 
 import org.junit.After;
 import org.junit.Assert;
@@ -101,11 +105,11 @@ public class ServantTest extends Assert {
         
         manager.setDestinationPolicy(dp);
         
-        Expires expires = RMUtils.getWSRMFactory().createExpires();
+        Expires expires = new Expires();
         expires.setValue(DatatypeFactory.createDuration("P0Y0M0DT0H0M0.0S"));
         Message message = createTestCreateSequenceMessage(expires, null);
 
-        CreateSequenceResponseType csr = servant.createSequence(message);
+        CreateSequenceResponseType csr = (CreateSequenceResponseType)servant.createSequence(message);
         
         Expires expires2 = csr.getExpires();
         
@@ -121,11 +125,11 @@ public class ServantTest extends Assert {
         dp.setSequenceExpiration(DURATION_SHORT);
         manager.setDestinationPolicy(dp);
         
-        Expires expires = RMUtils.getWSRMFactory().createExpires();
+        Expires expires = new Expires();
         expires.setValue(DURATION_DEFAULT);
         Message message = createTestCreateSequenceMessage(expires, null);
 
-        CreateSequenceResponseType csr = servant.createSequence(message);
+        CreateSequenceResponseType csr = (CreateSequenceResponseType)servant.createSequence(message);
         
         Expires expires2 = csr.getExpires();
         
@@ -140,12 +144,12 @@ public class ServantTest extends Assert {
         dp.setAcksPolicy(ap);
         manager.setDestinationPolicy(dp);
         
-        Expires expires = RMUtils.getWSRMFactory().createExpires();
+        Expires expires = new Expires();
         expires.setValue(DURATION_SHORT);
     
         Message message = createTestCreateSequenceMessage(expires, null);        
 
-        CreateSequenceResponseType csr = servant.createSequence(message);
+        CreateSequenceResponseType csr = (CreateSequenceResponseType)servant.createSequence(message);
         
         Expires expires2 = csr.getExpires();
         
@@ -161,12 +165,12 @@ public class ServantTest extends Assert {
         dp.setSequenceExpiration(DURATION_SHORT);
         manager.setDestinationPolicy(dp);
         
-        Expires expires = RMUtils.getWSRMFactory().createExpires();
+        Expires expires = new Expires();
         expires.setValue(DURATION_VERY_SHORT);
         
         Message message = createTestCreateSequenceMessage(expires, null);        
         
-        CreateSequenceResponseType csr = servant.createSequence(message);
+        CreateSequenceResponseType csr = (CreateSequenceResponseType)servant.createSequence(message);
         
         Expires expires2 = csr.getExpires();
         
@@ -187,15 +191,16 @@ public class ServantTest extends Assert {
         AttributedURIType id = ContextUtils.getAttributedURI(msgId);
         maps.setMessageID(id);
 
-        maps.setAction(ContextUtils.getAttributedURI(RMConstants.getCreateSequenceAction()));
+        maps.setAction(ContextUtils.getAttributedURI(RM10Constants.INSTANCE.getCreateSequenceAction()));
         maps.setTo(ContextUtils.getAttributedURI(SERVICE_URL));
 
         maps.setReplyTo(RMUtils.createReference(DECOUPLED_URL));
         
         message.put(JAXWSAConstants.SERVER_ADDRESSING_PROPERTIES_INBOUND, maps);
         
-        CreateSequenceType cs = RMUtils.getWSRMFactory().createCreateSequenceType();
-        cs.setAcksTo(RMUtils.createReference2004(DECOUPLED_URL));
+        CreateSequenceType cs = new CreateSequenceType();
+        cs.setAcksTo(org.apache.cxf.ws.addressing.VersionTransformer
+            .convert(RMUtils.createReference(DECOUPLED_URL)));
 
         cs.setExpires(expires);
         cs.setOffer(offer);
@@ -203,6 +208,8 @@ public class ServantTest extends Assert {
         MessageContentsList contents = new MessageContentsList();
         contents.add(cs);
         message.setContent(List.class, contents);
+
+        RMContextUtils.setProtocolVariation(message, ProtocolVariation.RM10WSA200408);
         
         return message;
     }
