@@ -59,7 +59,6 @@ import javax.xml.ws.soap.SOAPFaultException;
 import org.w3c.dom.Element;
 
 import org.apache.cxf.common.util.PackageUtils;
-import org.apache.cxf.helpers.CastUtils;
 import org.apache.cxf.helpers.DOMUtils;
 import org.apache.cxf.testutil.common.AbstractBusClientServerTestBase;
 import org.apache.cxf.testutil.common.TestUtil;
@@ -84,6 +83,12 @@ public class HandlerInvocationTest extends AbstractBusClientServerTestBase {
 
     @BeforeClass
     public static void startServers() throws Exception {
+        
+        //System.setProperty(SAAJFactoryResolver.MESSAGE_FACTORY_KEY, 
+        //                     "com.ibm.ws.webservices.engine.soap.MessageFactoryImpl");
+        //System.setProperty(SAAJFactoryResolver.SOAP_FACTORY_KEY, 
+        //    "com.ibm.ws.webservices.engine.xmlsoap.SOAPFactory");
+            
         assertTrue("server did not launch correctly", launchServer(Server.class, true));
     }
 
@@ -134,6 +139,7 @@ public class HandlerInvocationTest extends AbstractBusClientServerTestBase {
         
         BindingProvider bp1 = (BindingProvider)handlerTest1;
         Binding binding1 = bp1.getBinding();
+        @SuppressWarnings("rawtypes")
         List<Handler> port1HandlerChain = binding1.getHandlerChain();
         assertEquals(1, port1HandlerChain.size());
     }
@@ -216,7 +222,7 @@ public class HandlerInvocationTest extends AbstractBusClientServerTestBase {
 
         assertEquals(handlerNames.length, resp.size());
 
-        Iterator iter = resp.iterator();
+        Iterator<String> iter = resp.iterator();
         for (String expected : handlerNames) {
             assertEquals(expected, iter.next());
         }
@@ -341,7 +347,7 @@ public class HandlerInvocationTest extends AbstractBusClientServerTestBase {
             }
         };
         TestSOAPHandler soapHandler1 = new TestSOAPHandler(false);
-        TestSOAPHandler soapHandler2 = new TestSOAPHandler<SOAPMessageContext>(false) {
+        TestSOAPHandler soapHandler2 = new TestSOAPHandler(false) {
             public boolean handleMessage(SOAPMessageContext ctx) {
                 super.handleMessage(ctx);
                 Boolean outbound = (Boolean)ctx.get(MessageContext.MESSAGE_OUTBOUND_PROPERTY);
@@ -378,7 +384,7 @@ public class HandlerInvocationTest extends AbstractBusClientServerTestBase {
         TestHandler<LogicalMessageContext> handler1 = new TestHandler<LogicalMessageContext>(false);
         TestHandler<LogicalMessageContext> handler2 = new TestHandler<LogicalMessageContext>(false);
         TestSOAPHandler soapHandler1 = new TestSOAPHandler(false);
-        TestSOAPHandler soapHandler2 = new TestSOAPHandler<SOAPMessageContext>(false) {
+        TestSOAPHandler soapHandler2 = new TestSOAPHandler(false) {
             public boolean handleMessage(SOAPMessageContext ctx) {
                 super.handleMessage(ctx);
                 Boolean outbound = (Boolean)ctx.get(MessageContext.MESSAGE_OUTBOUND_PROPERTY);
@@ -618,7 +624,7 @@ public class HandlerInvocationTest extends AbstractBusClientServerTestBase {
 
         TestHandler<LogicalMessageContext> handler1 = new TestHandler<LogicalMessageContext>(false);
         TestHandler<LogicalMessageContext> handler2 = new TestHandler<LogicalMessageContext>(false);
-        TestSOAPHandler soapHandler1 = new TestSOAPHandler<SOAPMessageContext>(false) {
+        TestSOAPHandler soapHandler1 = new TestSOAPHandler(false) {
             public boolean handleMessage(SOAPMessageContext ctx) {
                 super.handleMessage(ctx);
                 Boolean outbound = (Boolean)ctx.get(MessageContext.MESSAGE_OUTBOUND_PROPERTY);
@@ -663,7 +669,7 @@ public class HandlerInvocationTest extends AbstractBusClientServerTestBase {
 
         TestHandler<LogicalMessageContext> handler1 = new TestHandler<LogicalMessageContext>(false);
         TestHandler<LogicalMessageContext> handler2 = new TestHandler<LogicalMessageContext>(false);
-        TestSOAPHandler soapHandler1 = new TestSOAPHandler<SOAPMessageContext>(false) {
+        TestSOAPHandler soapHandler1 = new TestSOAPHandler(false) {
             public boolean handleMessage(SOAPMessageContext ctx) {
                 super.handleMessage(ctx);
                 Boolean outbound = (Boolean)ctx.get(MessageContext.MESSAGE_OUTBOUND_PROPERTY);
@@ -708,7 +714,7 @@ public class HandlerInvocationTest extends AbstractBusClientServerTestBase {
 
         TestHandler<LogicalMessageContext> handler1 = new TestHandler<LogicalMessageContext>(false);
         TestHandler<LogicalMessageContext> handler2 = new TestHandler<LogicalMessageContext>(false);
-        TestSOAPHandler soapHandler1 = new TestSOAPHandler<SOAPMessageContext>(false) {
+        TestSOAPHandler soapHandler1 = new TestSOAPHandler(false) {
             public boolean handleMessage(SOAPMessageContext ctx) {
                 super.handleMessage(ctx);
                 Boolean outbound = (Boolean)ctx.get(MessageContext.MESSAGE_OUTBOUND_PROPERTY);
@@ -792,12 +798,11 @@ public class HandlerInvocationTest extends AbstractBusClientServerTestBase {
             assertNotNull(detail);
             
             QName nn = new QName("http://gizmos.com/orders/", "order");
-            Iterator<Element> it = CastUtils.cast(detail.getChildElements(nn));
-            assertTrue(it.hasNext());
-            Element el = it.next();
+            Element el = DOMUtils.getFirstChildWithName(detail, nn);
+            assertNotNull(el);
             el.normalize();
             assertEquals("Quantity element does not have a value", el.getFirstChild().getNodeValue());
-            el = it.next();
+            el = DOMUtils.getNextElement(el);
             el.normalize();
             assertEquals("Incomplete address: no zip code", el.getFirstChild().getNodeValue());
         }        
@@ -1125,7 +1130,7 @@ public class HandlerInvocationTest extends AbstractBusClientServerTestBase {
                 return true;
             }
         };
-        TestSOAPHandler soapHandler = new TestSOAPHandler<SOAPMessageContext>(false) {
+        TestSOAPHandler soapHandler = new TestSOAPHandler(false) {
             public boolean handleMessage(SOAPMessageContext ctx) {
                 super.handleMessage(ctx);
                 assertTrue("wsdl description not found or invalid", isValidWsdlDescription(ctx
@@ -1156,7 +1161,7 @@ public class HandlerInvocationTest extends AbstractBusClientServerTestBase {
         TestSOAPHandler soapHandler1 = new TestSOAPHandler(false);
         TestSOAPHandler soapHandler2 = new TestSOAPHandler(false);
 
-        addHandlersToChain((BindingProvider)disp, handler1, handler2, soapHandler1, soapHandler2);
+        addHandlersToChain(disp, handler1, handler2, soapHandler1, soapHandler2);
 
         InputStream is = getClass().getResourceAsStream("PingReq.xml");
         SOAPMessage outMsg = MessageFactory.newInstance().createMessage(null, is);
@@ -1182,10 +1187,10 @@ public class HandlerInvocationTest extends AbstractBusClientServerTestBase {
         String[] handlerNames = {"soapHandler4", "soapHandler3", "handler2", "handler1", "servant",
                                  "handler1", "handler2", "soapHandler3", "soapHandler4"};
 
-        List<String> resp = getHandlerNames(inMsg.getSOAPBody());
+        List<String> resp = getHandlerNames(inMsg.getSOAPPart().getEnvelope().getBody());
         assertEquals(handlerNames.length, resp.size());
 
-        Iterator iter = resp.iterator();
+        Iterator<String> iter = resp.iterator();
         for (String expected : handlerNames) {
             assertEquals(expected, iter.next());
         }
@@ -1205,10 +1210,11 @@ public class HandlerInvocationTest extends AbstractBusClientServerTestBase {
 
     }
 
-    void addHandlersToChain(BindingProvider bp, Handler... handlers) {
+    void addHandlersToChain(BindingProvider bp, Handler<?>... handlers) {
+        @SuppressWarnings("rawtypes")
         List<Handler> handlerChain = bp.getBinding().getHandlerChain();
         assertNotNull(handlerChain);
-        for (Handler h : handlers) {
+        for (Handler<?> h : handlers) {
             handlerChain.add(h);
         }
         bp.getBinding().setHandlerChain(handlerChain);
@@ -1230,15 +1236,17 @@ public class HandlerInvocationTest extends AbstractBusClientServerTestBase {
     }
 
     public class MyHandlerResolver implements HandlerResolver {
+        @SuppressWarnings("rawtypes")
         List<Handler> chain = new ArrayList<Handler>();
         String bindingID;
 
-        public MyHandlerResolver(Handler... handlers) {
-            for (Handler h : handlers) {
+        public MyHandlerResolver(Handler<?>... handlers) {
+            for (Handler<?> h : handlers) {
                 chain.add(h);
             }
         }
 
+        @SuppressWarnings("rawtypes")
         public List<Handler> getHandlerChain(PortInfo portInfo) {
             bindingID = portInfo.getBindingID();
             return chain;
